Skip to contents

Removes the sample name column, adds a column for the total allele count of this snarl, removes duplicated columns, and removes one allele. The total allele count is to avoid the effect in the parent snarl to leak to the current snarl.

Usage

preprocess_test_table(test_table)

Arguments

test_table

data.frame generated by combine_chunk_phenotype_covars

Value

a data.frame ready for a test