Prepare the phenotype/genotype/covariate table before a test
preprocess_test_table.RdRemoves the sample name column, adds a column for the total allele count of this snarl, removes duplicated columns, and removes one allele. The total allele count is to avoid the effect in the parent snarl to leak to the current snarl.